@@ -45,8 +45,10 @@ EVOLNOTCLONE = '13170'
 EVOLMOVE_CANNOT_MOVE_TO_CFO = '13633'
 EAGGRDOESNOTEXIST = '14420'
 EVOL_NOT_MOUNTED = '14716'
+EVSERVERALREADYSTARTED = '14923'
 ESIS_CLONE_NOT_LICENSED = '14956'
 EOBJECTNOTFOUND = '15661'
+EVSERVERNOTFOUND = '15698'
 E_VIFMGR_PORT_ALREADY_ASSIGNED_TO_BROADCAST_DOMAIN = '18605'
 ERELATION_EXISTS = '17122'
 ENOTRANSFER_IN_PROGRESS = '17130'
@@ -55,6 +57,7 @@ EANOTHER_OP_ACTIVE = '17131'
 ERELATION_NOT_QUIESCED = '17127'
 ESOURCE_IS_DIFFERENT = '17105'
 EVOL_CLONE_BEING_SPLIT = '17151'
+ESVMDR_CANNOT_PERFORM_OP_FOR_STATUS = '18815'
 
 
 class NaServer(object):
